aerosoltools.aerosol2d.Aerosol2D.correct_diffusion_losses — aerosoltools 0.1.0 documentation

# aerosoltools.aerosol2d.Aerosol2D.correct_diffusion_losses

Aerosol2D.correct_diffusion_losses(D_tube, L, Q, T=293, P=101300, inplace=True)

  Correct for diffusion losses in a sampling tube based on tubing geometry, flow conditions, and particle sizes.

  ## Parameters

  D_tubefloat

    Diameter of the tubing (in meters).

  Lfloat

    Length of the tubing (in meters).

  Qfloat

    Volumetric flow through the tubing (in L/min).

  Tfloat, optional

    Temperature in Kelvin. Default is 293 K.

  Pfloat, optional

    Pressure in Pascals. Default is 101300 Pa.

  inplacebool, optional

    Whether to modify the current instance or return a new one. Default is True.

  ## Returns

  Aerosol2D

    Instance with diffusion-corrected sizebin data.

  Parameters:

    - D_tube (float)

    - L (float)

    - Q (float)

    - T (float)

    - P (float)

    - inplace (bool)